==> dl.php?src=linea21_1_8.zip: linea21/languages/es/lang_search.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['search']['section'] = "buscar";



$lang['search']['result'] = "Buscar resultados";
$lang['search']['keywords'] = "Palabras clave : ";
$lang['search']['method'] = "Método : ";
$lang['search']['min_length']='se requieren al menos 3 caracteres';
$lang['search']['query_time']='Tiempo de consulta: ';
$lang['search']['query_seconds']='segundos';
$lang['search']['no_result'] = "no hay resultados";
$lang['search']['score'] = "relevancia";
$lang['search']['score_abbr'] = "rv";
$lang['search']['score_not_good'] = "no relevante";

$lang['search']['one_of_them'] = "una de las palabras";
$lang['search']['all_of_them'] = "todas las palabras";
$lang['search']['expression'] = "expresión completa";
$lang['search']['text_button'] = "Buscar";

$lang['search']['comment_module'] = "En comentarios";
$lang['search']['project_module'] = "En proyectos";
$lang['search']['news_module'] = "En noticias";
$lang['search']['page_module'] = "In pages"; // @todo translation
$lang['search']['newsletter_module'] = "En boletines";
$lang['search']['publication_module'] = "En publicaciones";
$lang['search']['det_publication_module'] = "En apartados de publicaciones";
$lang['search']['workshop_module'] = "En grupos de trabajo";
$lang['search']['workshoprep_module'] = "En informes";
$lang['search']['workshoprepcon_module'] = "En apartados de informes";
$lang['search']['workshopcal_module'] = "En el calendario";
$lang['search']['workshopcom_module'] = "En foros";
$lang['search']['sdi_module'] = 'En Indicadores de Desarrollo Sostenible';
$lang['search']['yellowpages_module'] = "En el directorio";
$lang['search']['user_module'] = "En el repositorio de usuarios";
$lang['search']['theme_module'] = "En áreas temáticas";
$lang['search']['scale_module'] = "En escalas";
$lang['search']['tag_module'] = "En tags";

$lang['search']['help']="Motor de búsqueda".SITE_LINEA_NAME;
$lang['search']['help_list1']="Para realizar una búsqueda global, haga click en 'Buscar' o escriba directamente una palabra clave en el cuadro situado debajo del menú de la izquierda";
$lang['search']['help_list2']="Para realizar una búsqueda en un módulo específico, entre en el módulo y haga click en 'Buscar'";
$lang['search']['help_list3']="El índice de relevancia se aplica a todos los documentos encontrados a través del motor de búsqueda; el documento más relevante es el que tiene mayor valor del índice.";

?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/es/lang_search.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['search']['section'] = "buscar";



$lang['search']['result'] = "Buscar resultados";
$lang['search']['keywords'] = "Palabras clave : ";
$lang['search']['method'] = "Método : ";
$lang['search']['min_length']='se requieren al menos 3 caracteres';
$lang['search']['query_time']='Tiempo de consulta: ';
$lang['search']['query_seconds']='segundos';
$lang['search']['no_result'] = "no hay resultados";
$lang['search']['score'] = "relevancia";
$lang['search']['score_abbr'] = "rv";
$lang['search']['score_not_good'] = "no relevante";

$lang['search']['one_of_them'] = "una de las palabras";
$lang['search']['all_of_them'] = "todas las palabras";
$lang['search']['expression'] = "expresión completa";
$lang['search']['expanded'] = "expanded search"; // @todo translation
$lang['search']['text_button'] = "Buscar";

$lang['search']['query_expansion_enabled'] = "Expanded search is eanabled (options are not available). A maximum of matches will be retrieved."; // @todo translation

$lang['search']['comment_module'] = "En comentarios";
$lang['search']['project_module'] = "En proyectos";
$lang['search']['news_module'] = "En noticias";
$lang['search']['page_module'] = "In pages"; // @todo translation
$lang['search']['newsletter_module'] = "En boletines";
$lang['search']['publication_module'] = "En publicaciones";
$lang['search']['det_publication_module'] = "En apartados de publicaciones";
$lang['search']['workshop_module'] = "En grupos de trabajo";
$lang['search']['workshoprep_module'] = "En informes";
$lang['search']['workshoprepcon_module'] = "En apartados de informes";
$lang['search']['workshopcal_module'] = "En el calendario";
$lang['search']['workshopcom_module'] = "En foros";
$lang['search']['sdi_module'] = 'En indicadores';
$lang['search']['yellowpages_module'] = "En el directorio";
$lang['search']['user_module'] = "En el repositorio de usuarios";
$lang['search']['level_module'] = "En niveles";
$lang['search']['scale_module'] = "En escalas";
$lang['search']['tag_module'] = "En tags";

$lang['search']['help']="Motor de búsqueda".SITE_LINEA_NAME;
$lang['search']['help_list1']="Para realizar una búsqueda global, haga click en 'Buscar' o escriba directamente una palabra clave en el cuadro situado debajo del menú de la izquierda";
$lang['search']['help_list2']="Para realizar una búsqueda en un módulo específico, entre en el módulo y haga click en 'Buscar'";
$lang['search']['help_list3']="El índice de relevancia se aplica a todos los documentos encontrados a través del motor de búsqueda; el documento más relevante es el que tiene mayor valor del índice.";

?>
